/*
 * Copyright (C) 2020 - 2024 ANSYS, Inc. and/or its affiliates.
 * SPDX-License-Identifier: MIT
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef _WUX_A661_EXT_H_4A1C85D0_3FBB_401C_958B_2E578EF73D08_
#define _WUX_A661_EXT_H_4A1C85D0_3FBB_401C_958B_2E578EF73D08_

/**
 * @file
 * @brief Declarations of the functions generated by the service A661UAA.
 *
 * The implementation relies on the ``lib/A661Connect.c`` runtime file,
 * derived from ``SCADE/lib/A661Cosim.c`` delivered with Ansys SCADE.
 */

#ifdef __cplusplus
extern "C" {
#endif

/* ---------------------------------------------------------------------------
 * A661 connection
 * ------------------------------------------------------------------------ */

/**
 * @brief Connect to the A661 server.
 *
 * Return 1 when the connection is successful, otherwise 0.
 *
 * Note: This function does nothing and returns 1 when there is no UA in the
 * project.
 *
 * @return int
 */
int WuxA661ConnectServer();
/**
 * @brief Disconnect from the A661 server.
 *
 * Return 1 when the disconnection is successful, otherwise 0.
 *
 * Note: This function does nothing and returns 1 when there is no UA in the
 * project.
 *
 * @return int
 */
int WuxA661DisconnectServer();
/**
 * @brief Send the A661 messages from the root operator outputs.
 *
 * Note: This function is empty when there is no UA in the project.
 */
void WuxA661SendMessages();
/**
 * @brief Receive the A661 messages and update the root operator inputs.
 *
 * Note: This function is empty when there is no UA in the project.
 */
void WuxA661ReceiveMessages();

#ifdef __cplusplus
}
#endif

#endif /* _WUX_A661_EXT_H_4A1C85D0_3FBB_401C_958B_2E578EF73D08_ */
