/*
 * Copyright (C) 2020 - 2024 ANSYS, Inc. and/or its affiliates.
 * SPDX-License-Identifier: MIT
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef _SDY_EXT_H_158ED1CF_4974_48A1_94C5_8EFC6007E589_
#define _SDY_EXT_H_158ED1CF_4974_48A1_94C5_8EFC6007E589_

/**
 * @file
 * @brief Declarations of the functions generated by the service SdyExt.
 *
 */

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief Call the initialization functions for all graphical panels.
 */
void WuxSdyInit();
/**
 * @brief Draw all the graphical panels.
 */
void WuxSdyDraw();
/**
 * @brief Set the graphical panels' input plugs from the root operators.
 */
void WuxSdySetInputs();
/**
 * @brief Update the root operator's inputs from the graphical panels' plugs.
 */
void WuxSdyGetOutputs();
/**
 * @brief Return whether a graphical panel window has been closed.
 * @return int
 *    1 if a window has been closed, otherwise 0.
 */
int WuxSdyCancelled();

#ifdef WUX_DISPLAY_AS_BUFFERS
/**
 * @brief Structure to access the raw image of a graphical panel.
 */
typedef struct _WuxSdyScreen
{
    const char* name;
    int width;
    int height;
    const char* buffer; /* RGBA */
    int size;
} WuxSdyScreen;

/**
 * @brief Return the number of graphical panels.
 * @return int
 */
int WuxSdyGetScreenCount();
/**
 * @brief Return the pointer to the raw image of a graphical panel.
 * @return const WuxSdyScreen*
 */
const WuxSdyScreen* WuxSdyGetScreen(int index);
#endif

#ifdef __cplusplus
}
#endif

#endif /* _SDY_EXT_H_158ED1CF_4974_48A1_94C5_8EFC6007E589_ */
